import { AutoComplete, AutoCompleteProps, Button, Empty, Space } from 'antd';
import React from 'react';
import { useSetState, useMount } from 'ahooks';

import { AppTitleBar } from '@package/components/app/title-bar.tsx';

import { queryStockInfo, searchStockList } from '@/stock-query/service/api.ts';
import { SecuritiesInfo } from '@/stock-query/service/types.ts';

import styles from './style.module.less';
import { formatMoney } from '@package/utils/strings.ts';


/**
 *   - 营业收入*10%＜1000万，输出1000万
 *   - 净利润*10%＜100万，输出100万
 *   - 净资产*10%＜1000万，输出1000万
 *   - 如果表格有结果为负数，输出绝对值
 * @param amount
 * @param minValue
 */
function formatStockMoney(amount: number, minValue = 1000) {
	if (amount < 0) amount = Math.abs(amount);
	return formatMoney(amount < minValue ? minValue : amount);
}
export default function StockQuery() {
	const [options, setOptions] = React.useState<AutoCompleteProps['options']>([]);

	const [state, setState] = useSetState<{
		companyName: string;
		result?: SecuritiesInfo;
		queried?: boolean;
	}>({
		companyName: ''
	});

	// 模糊查询证券列表
	const handleFilter = async (name: string) => {
		if (!name) {
			setOptions(() => []);
			return;
		}
		const list = await searchStockList(name);
		setOptions(list.security_names.map((name) => ({
			label: name,
			value: name
		})));
	};
	// 查询证券营收信息
	const handleSearch = async () => {
		if (!state.companyName) return;
		try {
			const result = await queryStockInfo(state.companyName);
			if (!result) return;
			setState({ result, queried: true });
		} catch (e) {
			console.log('query error:', e);
			setState({ result: undefined, queried: true });
		}
	};
	useMount(() => {
		chrome.webview?.hostObjects.host.SetTitle('交易权限速查');
	});

	return <>
		<AppTitleBar title="交易权限速查" backgroundColor={'#eddcb9'} />
		<div className={styles.stockQuery}>
			<Space size={20}>
				<AutoComplete
					style={{ width: 200 }}
					onSearch={handleFilter}
					placeholder="请输入证券名称"
					options={options}
					value={state.companyName}
					onChange={(companyName: string) => setState({ companyName })}
				/>
				<Button type="primary" onClick={handleSearch}>搜索</Button>
			</Space>
			<div style={{ minHeight: 200 }}>
				{state.queried && !state.result && <div className={styles.emptyQuery}>
					未找到该证券
				</div>}
				{state.queried && state.result && (
					<div className="result">
						<div className={styles.stockInfo}>
							<div>
								<span>证券代码：</span>
								<span>{state.result.securities_code}</span>
							</div>
							<div>
								<span>证券名称：</span>
								<span>{state.result.security_name}</span>
							</div>
						</div>
						<div className={styles.stockResult}>
							<table>
								<thead>
								<tr>
									<th className={styles.slashed}></th>
									<th>10%（单位：万元）</th>
									<th>50%（单位：万元）</th>
								</tr>
								</thead>
								<tbody>
								<tr>
									<td>营业收入</td>
									<td>{formatStockMoney(state.result.percent10.operating_income)}</td>
									<td>{formatStockMoney(state.result.percent50.operating_income)}</td>
								</tr>
								<tr>
									<td>净利润</td>
									<td>{formatStockMoney(state.result.percent10.net_profit,100)}</td>
									<td>{formatStockMoney(state.result.percent50.net_profit,100)}</td>
								</tr>
								<tr>
									<td>资产总额</td>
									<td>{formatMoney(state.result.percent10.total_assets)}</td>
									<td>{formatMoney(state.result.percent50.total_assets)}</td>
								</tr>
								<tr>
									<td>净资产</td>
									<td>{formatStockMoney(state.result.percent10.net_assets)}</td>
									<td>{formatStockMoney(state.result.percent50.net_assets)}</td>
								</tr>
								</tbody>
							</table>
						</div>
					</div>
				)}
			</div>
			<div className={styles.stockTips}>*科创板公司需额外注意市值指标(指交易前10个交易日收盘市值的算术平均值)</div>
		</div>
	</>;
}